aboutsummaryrefslogtreecommitdiffhomepage
path: root/include/gpu/GrProgramStageFactory.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/gpu/GrProgramStageFactory.h')
-rw-r--r--include/gpu/GrProgramStageFactory.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/include/gpu/GrProgramStageFactory.h b/include/gpu/GrProgramStageFactory.h
index 90f6b32851..385ebfe43a 100644
--- a/include/gpu/GrProgramStageFactory.h
+++ b/include/gpu/GrProgramStageFactory.h
@@ -12,12 +12,12 @@
#include "SkTemplates.h"
#include "GrNoncopyable.h"
/** Given a GrCustomStage of a particular type, creates the corresponding
graphics-backend-specific GrProgramStage. Also tracks equivalence
of shaders generated via a key.
*/
-class GrCustomStage;
+class GrEffect;
class GrGLProgramStage;
class GrGLCaps;
@@ -29,10 +29,10 @@ public:
kTexturingStageKeyBits = 6
};
- virtual StageKey glStageKey(const GrCustomStage& stage,
+ virtual StageKey glStageKey(const GrEffect& stage,
const GrGLCaps& caps ) const = 0;
virtual GrGLProgramStage* createGLInstance(
- const GrCustomStage& stage) const = 0;
+ const GrEffect& stage) const = 0;
bool operator ==(const GrProgramStageFactory& b) const {
return fStageClassID == b.fStageClassID;
@@ -73,17 +73,17 @@ class GrTProgramStageFactory : public GrProgramStageFactory {
public:
typedef typename StageClass::GLProgramStage GLProgramStage;
/** Returns a human-readable name that is accessible via GrCustomStage or
GrGLProgramStage and is consistent between the two of them.
*/
virtual const char* name() const SK_OVERRIDE { return StageClass::Name(); }
/** Returns a value that idenitifes the GLSL shader code generated by
- a GrCustomStage. This enables caching of generated shaders. Part of the
+ a GrEffect. This enables caching of generated shaders. Part of the
id identifies the GrCustomShader subclass. The remainder is based
- on the aspects of the GrCustomStage object's configuration that affect
+ on the aspects of the GrEffect object's configuration that affect
GLSL code generation. */
- virtual StageKey glStageKey(const GrCustomStage& stage,
+ virtual StageKey glStageKey(const GrEffect& stage,
const GrGLCaps& caps) const SK_OVERRIDE {
GrAssert(kIllegalStageClassID != fStageClassID);
StageKey stageID = GLProgramStage::GenKey(stage, caps);
@@ -101,10 +101,10 @@ public:
}
/** Returns a new instance of the appropriate *GL* implementation class
- for the given GrCustomStage; caller is responsible for deleting
+ for the given GrEffect; caller is responsible for deleting
the object. */
virtual GLProgramStage* createGLInstance(
- const GrCustomStage& stage) const SK_OVERRIDE {
+ const GrEffect& stage) const SK_OVERRIDE {
return SkNEW_ARGS(GLProgramStage, (*this, stage));
}
@@ -12,12 +12,12 @@
#include "SkTemplates.h"
#include "GrNoncopyable.h"
-/** Given a GrCustomStage of a particular type, creates the corresponding
+/** Given a GrEffect of a particular type, creates the corresponding
graphics-backend-specific GrProgramStage. Also tracks equivalence
of shaders generated via a key.
@@ -73,17 +73,17 @@ class GrTProgramStageFactory : public GrProgramStageFactory {
public:
typedef typename StageClass::GLProgramStage GLProgramStage;
- /** Returns a human-readable name that is accessible via GrCustomStage or
+ /** Returns a human-readable name that is accessible via GrEffect or
GrGLProgramStage and is consistent between the two of them.
*/